==> ktorrent_5.1.1.orig.tar.xz: ktorrent-5.1.1/plugins/stats/DisplaySettingsPage.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KTDISPLAYSETTINGSPAGE_H
#define KTDISPLAYSETTINGSPAGE_H

#include <interfaces/prefpageinterface.h>
#include "ui_DisplaySettings.h"

namespace kt
{

    /**
        @author
    */

    class DisplaySettingsPage : public PrefPageInterface, public Ui_DisplaySettingsWgt
    {
    public:
        DisplaySettingsPage(QWidget* parent);
        ~DisplaySettingsPage();
    };

}

#endif

==> ktorrent_5.2.0.orig.tar.xz: ktorrent-5.2.0/plugins/stats/DisplaySettingsPage.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef KTDISPLAYSETTINGSPAGE_H
#define KTDISPLAYSETTINGSPAGE_H

#include <interfaces/prefpageinterface.h>
#include "ui_DisplaySettings.h"

namespace kt
{

    /**
        @author
    */

    class DisplaySettingsPage : public PrefPageInterface, public Ui_DisplaySettingsWgt
    {
    public:
        DisplaySettingsPage(QWidget* parent);
        ~DisplaySettingsPage() override;
    };

}

#endif
